# Sessions

A "session" is a collection of tabs and sub-windows that can be saved and restored
later. Sessions are useful for saving your work halfway through.

## Basic Usage

## Restore a Session by Workflows
